@@ -41,20 +41,13 @@ void CompositeFileTransferJob::startNextSubJob()
     m_currentJob = qobject_cast<FileTransferJob *>(subjobs().at(0));
     m_currentJobSentPayloadSize = 0;
 
+    m_currentJob->start();
     Q_EMIT description(this,
                        i18ncp("@title job", "Receiving file", "Receiving files", m_totalJobs),
                        {i18nc("The source of a file operation", "Source"), Daemon::instance()->getDevice(this->m_deviceId)->name()},
                        {i18nc("The destination of a file operation", "Destination"), m_currentJob->destination().toDisplayString(QUrl::PreferLocalFile)});
 
-    m_currentJob->start();
-#ifdef SAILFISHOS
-    connect(m_currentJob, SIGNAL(processedAmount(KJob *, KJob::Unit, qulonglong)), this, SLOT(slotProcessedAmount(KJob *, KJob::Unit, qulonglong)));
-#else
-    connect(m_currentJob,
-            QOverload<KJob *, KJob::Unit, qulonglong>::of(&FileTransferJob::processedAmount),
-            this,
-            &CompositeFileTransferJob::slotProcessedAmount);
-#endif
+    connect(m_currentJob, &FileTransferJob::processedAmountChanged, this, &CompositeFileTransferJob::slotProcessedAmount);
 }
 
 bool CompositeFileTransferJob::addSubjob(KJob *job)
@@ -93,10 +86,8 @@ bool CompositeFileTransferJob::doKill()
     return true;
 }
 
-void CompositeFileTransferJob::slotProcessedAmount(KJob *job, KJob::Unit unit, qulonglong amount)
+void CompositeFileTransferJob::slotProcessedAmount(KJob * /*job*/, KJob::Unit unit, qulonglong amount)
 {
-    Q_UNUSED(job);
-
     m_currentJobSentPayloadSize = amount;
     const auto totalSent = m_totalSentPayloadSize + m_currentJobSentPayloadSize;
 
@@ -141,3 +132,5 @@ void CompositeFileTransferJob::slotResult(KJob *job)
         emitResult();
     }
 }
+
+#include "moc_compositefiletransferjob.cpp"
