@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef CLIPBOARDLISTENER_H
-#define CLIPBOARDLISTENER_H
+#pragma once
 
 #include <QClipboard>
 #include <QObject>
@@ -56,5 +55,3 @@ private:
 #endif
     KSystemClipboard *clipboard;
 };
-
-#endif
