@@ -10,12 +10,10 @@
 #include <PulseAudioQt/Context>
 #include <PulseAudioQt/Sink>
 
-#include "mprisplayer.h"
+#include "generated/systeminterfaces/mprisplayer.h"
 #include <dbushelper.h>
 
-// In older Qt released, qAsConst isnt available
 #include "plugin_pausemusic_debug.h"
-#include "qtcompat_p.h"
 
 K_PLUGIN_CLASS_WITH_JSON(PauseMusicPlugin, "kdeconnect_pausemusic.json")
 
@@ -25,17 +23,17 @@ PauseMusicPlugin::PauseMusicPlugin(QObject *parent, const QVariantList &args)
 {
 }
 
-bool PauseMusicPlugin::receivePacket(const NetworkPacket &np)
+void PauseMusicPlugin::receivePacket(const NetworkPacket &np)
 {
     bool pauseOnlyWhenTalking = config()->getBool(QStringLiteral("conditionTalking"), false);
 
     if (pauseOnlyWhenTalking) {
         if (np.get<QString>(QStringLiteral("event")) != QLatin1String("talking")) {
-            return true;
+            return;
         }
     } else { // Pause as soon as it rings
         if (np.get<QString>(QStringLiteral("event")) != QLatin1String("ringing") && np.get<QString>(QStringLiteral("event")) != QLatin1String("talking")) {
-            return true;
+            return;
         }
     }
 
@@ -104,8 +102,7 @@ bool PauseMusicPlugin::receivePacket(const NetworkPacket &np)
             pausedSources.clear();
         }
     }
-
-    return true;
 }
 
+#include "moc_pausemusicplugin.cpp"
 #include "pausemusicplugin.moc"
