@@ -12,6 +12,7 @@
 
 #include <KLocalizedString>
 
+#include "dbushelpers.h"
 #include "interfaces/conversationmessage.h"
 #include "interfaces/dbusinterfaces.h"
 #include "sms_conversations_list_debug.h"
@@ -26,6 +27,7 @@ ConversationListModel::ConversationListModel(QObject *parent)
 {
     // qCDebug(KDECONNECT_SMS_CONVERSATIONS_LIST_MODEL) << "Constructing" << this;
     auto roles = roleNames();
+    roles.insert(Qt::DisplayRole, "displayNames");
     roles.insert(FromMeRole, "fromMe");
     roles.insert(SenderRole, "sender");
     roles.insert(DateRole, "date");
@@ -55,8 +57,8 @@ void ConversationListModel::setDeviceId(const QString &deviceId)
     qCDebug(KDECONNECT_SMS_CONVERSATIONS_LIST_MODEL) << "setDeviceId" << deviceId << "of" << this;
 
     if (m_conversationsInterface) {
-        disconnect(m_conversationsInterface, SIGNAL(conversationCreated(QDBusVariant)), this, SLOT(handleCreatedConversation(QDBusVariant)));
-        disconnect(m_conversationsInterface, SIGNAL(conversationUpdated(QDBusVariant)), this, SLOT(handleConversationUpdated(QDBusVariant)));
+        disconnect(m_conversationsInterface, &DeviceConversationsDbusInterface::conversationCreated, this, &ConversationListModel::handleCreatedConversation);
+        disconnect(m_conversationsInterface, &DeviceConversationsDbusInterface::conversationUpdated, this, &ConversationListModel::handleConversationUpdated);
         delete m_conversationsInterface;
         m_conversationsInterface = nullptr;
     }
@@ -72,8 +74,8 @@ void ConversationListModel::setDeviceId(const QString &deviceId)
     Q_EMIT deviceIdChanged();
 
     m_conversationsInterface = new DeviceConversationsDbusInterface(deviceId, this);
-    connect(m_conversationsInterface, SIGNAL(conversationCreated(QDBusVariant)), this, SLOT(handleCreatedConversation(QDBusVariant)));
-    connect(m_conversationsInterface, SIGNAL(conversationUpdated(QDBusVariant)), this, SLOT(handleConversationUpdated(QDBusVariant)));
+    connect(m_conversationsInterface, &DeviceConversationsDbusInterface::conversationCreated, this, &ConversationListModel::handleCreatedConversation);
+    connect(m_conversationsInterface, &DeviceConversationsDbusInterface::conversationUpdated, this, &ConversationListModel::handleConversationUpdated);
 
     refresh();
 }
@@ -182,7 +184,7 @@ void ConversationListModel::createRowFromMessage(const ConversationMessage &mess
         const QIcon displayIcon = SmsHelper::getIconForAddresses(rawAddresses);
 
         item->setText(displayNames);
-        item->setIcon(displayIcon);
+        item->setData(displayIcon.name(), Qt::DecorationRole);
         item->setData(message.threadID(), ConversationIdRole);
         item->setData(rawAddresses[0].address(), SenderRole);
     }
@@ -294,3 +296,5 @@ void ConversationListModel::createConversationForAddress(const QString &address)
     item->setData(address, SenderRole);
     appendRow(item);
 }
+
+#include "moc_conversationlistmodel.cpp"
